$ErrorActionPreference  = 'Stop';

# Make sure to kill any presencelight processes before attempting an
# installation. This covers the case that PresenceLight is currently
# installed outside of Chocolatey
Get-Process presencelight* -ErrorAction SilentlyContinue | Stop-Process

$WindowsVersion=[Environment]::OSVersion.Version
if ($WindowsVersion.Major -ne "10") {
  throw "This package requires Windows 10."
}

$IsCorrectBuild=[Environment]::OSVersion.Version.Build
if ($IsCorrectBuild -lt "17134") {
  throw "This package requires at least Windows 10 version build 17134.x."
}

$packageName    = "presencelight"
$toolsDir       = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$InstallDir     = Join-Path $env:APPDATA 'PresenceLight'

$pp = Get-PackageParameters

if($pp['InstallDir']){
  $InstallDir = $pp['InstallDir']
}

$packageArgs = @{
  packageName    = $packageName
  unzipLocation  = $InstallDir
  urlARM         = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.0.19/PresenceLight.5.0.19-win-arm64.zip"
  url86bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.0.19/PresenceLight.5.0.19-x86.zip"
  url64bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.0.19/PresenceLight.5.0.19-x64.zip"
  checksumARM    = "CEBB442001F182B9B9E2196A7544E57435E9848100664F897F905EF3D0C31C5A"
  checksum       = "A0FDB71D5EF32C5193F3F386909DA693565337F9906E0A0F3E9FA9560FA7085F"
  checksum64     = "3E6319B85173F795C5B20881718A5CF3E2E0A3AFCE267416C2851B4FD7B9E424"
  checksumType   = 'SHA256'
}

Install-ChocolateyZipPackage @packageArgs

$exePath = Join-Path $InstallDir 'PresenceLight.exe'


Write-Output "Adding shortcut to Start Menu"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

Write-Output "Adding shortcut to Startup"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\Startup\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

